@@ -1,5 +1,5 @@
-assign("rbfST.cv1",  
-       function (param, formula, data, n.neigh, func) 
+assign("rbfST.cv1",
+       function (param, formula, data, n.neigh, func)
        {
 eta <- param[1]
 rho <- param[2]
@@ -7,9 +7,9 @@ s = cbind(coordinates(data),data["t"]@data)
 s0 = cbind(coordinates(data),data["t"]@data)
 z = extractFormula(formula, data, data)$z
 X0 = extractFormula(formula, data, data)$X
-S <- scale(s)  
+S <- scale(s)
 dist.S <- rdist(S)-diag(rdist(S))
-rbf0 <- function(S, z, X0, x0, dist.S, eta, rho, n.neigh, func){     
+rbf0 <- function(S, z, X0, x0, dist.S, eta, rho, n.neigh, func){
   vec.orden <- order(dist.S)
   vc <- vec.orden[1:n.neigh]
   dist.vec.cerca <- dist.S[vc]
@@ -21,14 +21,14 @@ rbf0 <- function(S, z, X0, x0, dist.S, eta, rho, n.neigh, func){
   b <- RBF.phi(dist.vec.cerca,eta,func)
   I.PHI <- if (func %in% c("M","ST","CRS","TPS","TRI")) solve(PHI)
   else chol2inv(chol(PHI))
-  Lambda <- I.PHI%*%(b-as.matrix(X)%*%(Solve(t(X)%*%I.PHI%*%X))%*%(t(X)%*%I.PHI%*%b-x0))
+  Lambda <- I.PHI%*%(b-as.matrix(X)%*%(ginv(t(X)%*%I.PHI%*%X))%*%(t(X)%*%I.PHI%*%b-x0))
   pred <- t(Lambda)%*%z[vc]
   pred
-}      
+}
 pred <- as.numeric(NA,length= length(z))
 #pb <- txtProgressBar(min = 0, max = length(z), char = "=", style = 3)
-for(i in 1:(length(z))){                                                
-  pred[i] <-  rbf0(S=S[-i,], z, X0=as.matrix(X0[-i,]), x0=as.matrix(X0[i,]), dist.S=dist.S[i,-i], eta, rho, n.neigh, func)  
+for(i in 1:(length(z))){
+  pred[i] <-  rbf0(S=S[-i,], z, X0=as.matrix(X0[-i,]), x0=as.matrix(X0[i,]), dist.S=dist.S[i,-i], eta, rho, n.neigh, func)
 #  setTxtProgressBar(pb, i)
 }
 #close(pb)
